@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-2000 by Solar Designer
+ * Copyright (c) 1996-2000,2003 by Solar Designer
  */
 
 #include <stdio.h>
@@ -306,8 +306,8 @@ static void c_free_ident(struct c_ident *list, struct c_ident *globals)
 
 	while ((current = list) != globals) {
 		list = list->next;
-		mem_free((void **)&current->name);
-		mem_free((void **)&current);
+		MEM_FREE(current->name);
+		MEM_FREE(current);
 	}
 }
 
@@ -337,7 +337,7 @@ static void c_free_fixup(struct c_fixup *list, union c_insn *pc)
 			current->pc->pc = pc;
 
 		list = list->next;
-		mem_free((void **)&current);
+		MEM_FREE(current);
 	}
 }
 
