@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-2003 by Solar Designer
+ * Copyright (c) 1996-2004 by Solar Designer
  */
 
 #include <stdio.h>
@@ -161,10 +161,10 @@ static void john_load(void)
 				ldr_show_pw_file(&database, current->data);
 			} while ((current = current->next));
 
-			printf("%s%d password%s cracked, %d left\n",
+			printf("%s%d password hash%s cracked, %d left\n",
 				database.guess_count ? "\n" : "",
 				database.guess_count,
-				database.guess_count != 1 ? "s" : "",
+				database.guess_count != 1 ? "es" : "",
 				database.password_count -
 				database.guess_count);
 
@@ -260,6 +260,7 @@ static void john_run(void)
 	else
 	if (options.flags & FLG_CRACKING_CHK) {
 		if (!(options.flags & FLG_STDOUT)) {
+			status_init(NULL, 1);
 			log_init(LOG_NAME, POT_NAME, options.session);
 			john_log_format();
 			if (cfg_get_bool(SECTION_OPTIONS, NULL, "Idle"))
