@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2000 by Solar Designer
  */
 
 /*
@@ -10,15 +10,15 @@
 #ifndef _JOHN_ARCH_H
 #define _JOHN_ARCH_H
 
-#define ARCH_GENERIC			1
 #define ARCH_WORD			long
 #define ARCH_SIZE			8
 #define ARCH_BITS			64
+#define ARCH_BITS_LOG			6
 #define ARCH_BITS_STR			"64"
 #define ARCH_LITTLE_ENDIAN		0
 #define ARCH_INT_GT_32			0
 #define ARCH_ALLOWS_UNALIGNED		0
-#define ARCH_INDEX			unsigned int
+#define ARCH_INDEX(x)			((unsigned int)(unsigned char)(x))
 
 #define OS_TIMER			1
 #define OS_FLOCK			1
@@ -32,10 +32,14 @@
 #define DES_SCALE			0
 #define DES_EXTB			0
 #define DES_COPY			0
+#define DES_BS_ASM			0
 #define DES_BS				1
+#define DES_BS_VECTOR			0
+#define DES_BS_EXPAND			1
 
 #define MD5_ASM				0
-#define MD5_IMM				1
+#define MD5_X2				1
+#define MD5_IMM				0
 
 #define BF_ASM				0
 #define BF_SCALE			0
